@@ -26,7 +26,9 @@ import jsonlines
 import pendulum
 import requests
 from airflow.exceptions import AirflowSkipException
-from airflow.models.taskinstance import TaskInstance
+from tenacity import RetryError, retry, stop_after_attempt, wait_exponential, wait_fixed
+
+from academic_observatory_workflows.config import schema_folder as default_schema_folder
 from observatory.platform.utils.airflow_utils import AirflowVars
 from observatory.platform.utils.url_utils import get_user_agent
 from observatory.platform.utils.workflow_utils import upload_files_from_list
@@ -34,9 +36,6 @@ from observatory.platform.workflows.stream_telescope import (
     StreamRelease,
     StreamTelescope,
 )
-from tenacity import RetryError, retry, stop_after_attempt, wait_exponential, wait_fixed
-
-from academic_observatory_workflows.config import schema_folder as default_schema_folder
 
 
 class CrossrefEventsRelease(StreamRelease):
@@ -220,7 +219,6 @@ class CrossrefEventsTelescope(StreamTelescope):
         dataset_description: str = "The Crossref Events dataset: https://www.eventdata.crossref.org/guide/",
         queue: str = "remote_queue",
         merge_partition_field: str = "id",
-        bq_merge_days: int = 7,
         schema_folder: str = default_schema_folder(),
         batch_load: bool = True,
         airflow_vars: List = None,
@@ -237,7 +235,6 @@ class CrossrefEventsTelescope(StreamTelescope):
         :param dataset_description: the dataset description.
         :param queue: the queue that the tasks should run on.
         :param merge_partition_field: the BigQuery field used to match partitions for a merge
-        :param bq_merge_days: how often partitions should be merged (every x days)
         :param schema_folder: the SQL schema path.
         :param batch_load: whether all files in the transform folder are loaded into 1 table at once
         :param airflow_vars: list of airflow variable keys, for each variable it is checked if it exists in airflow
@@ -260,12 +257,12 @@ class CrossrefEventsTelescope(StreamTelescope):
             schedule_interval,
             dataset_id,
             merge_partition_field,
-            bq_merge_days,
             schema_folder,
             dataset_description=dataset_description,
             queue=queue,
             batch_load=batch_load,
             airflow_vars=airflow_vars,
+            load_bigquery_table_kwargs={"ignore_unknown_values": True},
         )
         self.mailto = mailto
         self.max_threads = max_threads
