@@ -24,6 +24,7 @@ import os
 import shutil
 import subprocess
 from concurrent.futures import ProcessPoolExecutor, as_completed
+from datetime import datetime
 from subprocess import Popen
 from typing import Dict, List
 
@@ -34,8 +35,6 @@ from airflow.exceptions import AirflowException
 from airflow.hooks.base import BaseHook
 from bs4 import BeautifulSoup
 from natsort import natsorted
-
-from academic_observatory_workflows.config import schema_folder as default_schema_folder
 from observatory.platform.utils.airflow_utils import AirflowConns, AirflowVars
 from observatory.platform.utils.proc_utils import wait_for_process
 from observatory.platform.utils.url_utils import retry_session
@@ -45,6 +44,8 @@ from observatory.platform.workflows.snapshot_telescope import (
     SnapshotTelescope,
 )
 
+from academic_observatory_workflows.config import schema_folder as default_schema_folder
+
 
 class CrossrefMetadataRelease(SnapshotRelease):
     def __init__(self, dag_id: str, release_date: pendulum.DateTime):
@@ -217,6 +218,10 @@ class CrossrefMetadataTelescope(SnapshotTelescope):
             ]
         if airflow_conns is None:
             airflow_conns = [AirflowConns.CROSSREF]
+
+        if load_bigquery_table_kwargs is None:
+            load_bigquery_table_kwargs = {"ignore_unknown_values": True}
+
         super().__init__(
             dag_id,
             start_date,
@@ -224,8 +229,8 @@ class CrossrefMetadataTelescope(SnapshotTelescope):
             dataset_id,
             schema_folder,
             queue=queue,
-            load_bigquery_table_kwargs=load_bigquery_table_kwargs,
             dataset_description=dataset_description,
+            load_bigquery_table_kwargs=load_bigquery_table_kwargs,
             table_descriptions=table_descriptions,
             airflow_vars=airflow_vars,
             airflow_conns=airflow_conns,
@@ -399,6 +404,14 @@ def transform_item(item):
                 if None in v:
                     # "date-parts" : [ [ null ] ]
                     v = []
+            elif k == "award":
+                if isinstance(v, str):
+                    v = [v]
+            elif k == "date_time":
+                try:
+                    datetime.strptime(v, "%Y-%m-%dT%H:%M:%SZ")
+                except ValueError:
+                    v = ""
 
             new[k] = transform_item(v)
         return new
