@@ -82,8 +82,7 @@ def make_dataset_transforms(
     dataset_id_crossref_events: str = "crossref",
     dataset_id_crossref_metadata: str = "crossref",
     dataset_id_crossref_fundref: str = "crossref",
-    dataset_id_grid: str = "digital_science",
-    dataset_id_iso: str = "iso",
+    dataset_id_ror: str = "ror",
     dataset_id_mag: str = "mag",
     dataset_id_orcid: str = "orcid",
     dataset_id_open_citations: str = "open_citations",
@@ -111,11 +110,10 @@ def make_dataset_transforms(
             ),
             Transform(
                 inputs={
-                    "grid": Table(dataset_id_grid, "grid", sharded=True),
-                    "iso": Table(dataset_id_iso),
+                    "ror": Table(dataset_id_ror, "ror", sharded=True),
                     "settings": Table(dataset_id_settings),
                 },
-                output_table=Table(dataset_id_observatory_intermediate, "grid"),
+                output_table=Table(dataset_id_observatory_intermediate, "ror"),
             ),
             Transform(
                 inputs={
@@ -139,7 +137,7 @@ def make_dataset_transforms(
                 output_clustering_fields=["doi"],
             ),
             Transform(
-                inputs={"unpaywall": Table(dataset_id_unpaywall, "unpaywall", sharded=True)},
+                inputs={"unpaywall": Table(dataset_id_unpaywall, "unpaywall", sharded=False)},
                 output_table=Table(dataset_id_observatory_intermediate, "unpaywall"),
                 output_cluster=True,
                 output_clustering_fields=["doi"],
@@ -290,8 +288,7 @@ class DoiWorkflow(Workflow):
         "crossref_metadata",
         "crossref_fundref",
         "geonames",
-        "grid",
-        "mag",
+        "ror",
         "open_citations",
         "unpaywall",
         "orcid",
@@ -426,16 +423,17 @@ class DoiWorkflow(Workflow):
 
     def create_tasks(self):
         # Add sensors
-        for ext_dag_id in self.SENSOR_DAG_IDS:
-            sensor = DagRunSensor(
-                task_id=f"{ext_dag_id}_sensor",
-                external_dag_id=ext_dag_id,
-                mode="reschedule",
-                duration=timedelta(days=7),  # Look back up to 7 days from execution date
-                poke_interval=int(timedelta(hours=1).total_seconds()),  # Check at this interval if dag run is ready
-                timeout=int(timedelta(days=2).total_seconds()),  # Sensor will fail after 2 days of waiting
-            )
-            self.add_sensor(sensor)
+        with self.parallel_tasks():
+            for ext_dag_id in self.SENSOR_DAG_IDS:
+                sensor = DagRunSensor(
+                    task_id=f"{ext_dag_id}_sensor",
+                    external_dag_id=ext_dag_id,
+                    mode="reschedule",
+                    duration=timedelta(days=7),  # Look back up to 7 days from execution date
+                    poke_interval=int(timedelta(hours=1).total_seconds()),  # Check at this interval if dag run is ready
+                    timeout=int(timedelta(days=2).total_seconds()),  # Sensor will fail after 2 days of waiting
+                )
+                self.add_operator(sensor)
 
         # Setup tasks
         self.add_setup_task(self.check_dependencies)
