@@ -148,7 +148,10 @@ class OrcidRelease(StreamRelease):
             "activate-service-account",
             f"--key-file" f"={os.environ['GOOGLE_APPLICATION_CREDENTIALS']}",
         ]
-        proc: Popen = subprocess.Popen(args, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+        # Set env variable to fix gcloud error, see https://issuetracker.google.com/issues/217589135
+        proc: Popen = subprocess.Popen(
+            args, stdout=subprocess.PIPE, stderr=subprocess.PIPE, env=dict(os.environ, CLOUDSDK_PYTHON="python3")
+        )
         run_subprocess_cmd(proc, args)
 
         logging.info(f"Downloading transferred files from Google Cloud bucket: {gc_download_bucket}")
@@ -245,7 +248,6 @@ class OrcidTelescope(StreamTelescope):
         table_descriptions: dict = None,
         queue: str = "remote_queue",
         merge_partition_field: str = "orcid_identifier.uri",
-        bq_merge_days: int = 7,
         schema_folder: str = default_schema_folder(),
         batch_load: bool = True,
         airflow_vars: List = None,
@@ -262,7 +264,6 @@ class OrcidTelescope(StreamTelescope):
         :param queue: the queue that the telescope should run on.
         :param table_descriptions: a dictionary with table ids and corresponding table descriptions.
         :param merge_partition_field: the BigQuery field used to match partitions for a merge
-        :param bq_merge_days: how often partitions should be merged (every x days)
         :param schema_folder: the SQL schema path.
         :param batch_load: whether all files in the transform folder are loaded into 1 table at once
         :param airflow_vars: list of airflow variable keys, for each variable it is checked if it exists in airflow
@@ -293,7 +294,6 @@ class OrcidTelescope(StreamTelescope):
             schedule_interval,
             dataset_id,
             merge_partition_field,
-            bq_merge_days,
             schema_folder,
             dataset_description=dataset_description,
             table_descriptions=table_descriptions,
@@ -301,6 +301,7 @@ class OrcidTelescope(StreamTelescope):
             airflow_vars=airflow_vars,
             airflow_conns=airflow_conns,
             batch_load=batch_load,
+            load_bigquery_table_kwargs={"ignore_unknown_values": True},
         )
         self.max_processes = max_processes
 
@@ -322,9 +323,7 @@ class OrcidTelescope(StreamTelescope):
 
         start_date, end_date, first_release = self.get_release_info(**kwargs)
 
-        release = OrcidRelease(
-            self.dag_id, start_date, end_date, first_release, self.max_processes
-        )
+        release = OrcidRelease(self.dag_id, start_date, end_date, first_release, self.max_processes)
         return release
 
     def check_dependencies(self, **kwargs) -> bool:
