@@ -59,14 +59,14 @@ class TestCrossrefMetadataTelescope(ObservatoryTestCase):
         self.data_location = os.getenv("TEST_GCP_DATA_LOCATION")
         self.download_path = test_fixtures_folder("crossref_metadata", "crossref_metadata.json.tar.gz")
         self.extract_file_hashes = [
-            "4a55065d90aaa58c69bc5f5a54da3006",
+            "42cab8ed20ef20bed51dacd3dc364589",
             "c45901a52154789470410aad51485e9c",
             "4c0fd617224a557b9ef04313cca0bd4a",
             "d93dc613e299871925532d906c3a44a1",
             "dd1ab247c55191a14bcd1bf32719c337",
         ]
         self.transform_hashes = [
-            "065a8c0bd1ef4239be9f37c0ad199a31",
+            "a2be39d3c4d4c9dc20af768f8ae35476",
             "38b766ec494054e621787de00ff715c8",
             "70437aad7c4568ed07408baf034871e4",
             "c3e3285a48867c8b7c10b1c9c0c5ab8a",
@@ -121,7 +121,7 @@ class TestCrossrefMetadataTelescope(ObservatoryTestCase):
         dataset_id = env.add_dataset()
 
         # Setup Telescope
-        execution_date = pendulum.datetime(year=2020, month=11, day=1)
+        execution_date = pendulum.datetime(year=2022, month=1, day=1)
         telescope = CrossrefMetadataTelescope(dataset_id=dataset_id)
         dag = telescope.make_dag()
 
@@ -132,7 +132,7 @@ class TestCrossrefMetadataTelescope(ObservatoryTestCase):
                 env.add_connection(Connection(conn_id=AirflowConns.CROSSREF, uri="mysql://:crossref-token@"))
 
                 # Test that all dependencies are specified: no error should be thrown
-                env.run_task(telescope.check_dependencies.__name__, dag, execution_date)
+                env.run_task(telescope.check_dependencies.__name__)
 
                 # Test check release exists task, next tasks should not be skipped
                 with httpretty.enabled():
@@ -140,43 +140,43 @@ class TestCrossrefMetadataTelescope(ObservatoryTestCase):
                         year=execution_date.year, month=execution_date.month
                     )
                     httpretty.register_uri(httpretty.HEAD, url, body="", status=302)
-                    env.run_task(telescope.check_release_exists.__name__, dag, execution_date)
+                    env.run_task(telescope.check_release_exists.__name__)
 
                 release = CrossrefMetadataRelease(telescope.dag_id, execution_date)
 
                 # Test download task
                 with httpretty.enabled():
                     self.setup_mock_file_download(release.url, self.download_path)
-                    env.run_task(telescope.download.__name__, dag, execution_date)
+                    env.run_task(telescope.download.__name__)
                 self.assertEqual(1, len(release.download_files))
-                expected_file_hash = "10210c33936f9ba6b7e053f6f457591b"
+                expected_file_hash = "047770ae386f3376c08e3975d7f06016"
                 self.assert_file_integrity(release.download_path, expected_file_hash, "md5")
 
                 # Test that file uploaded
-                env.run_task(telescope.upload_downloaded.__name__, dag, execution_date)
+                env.run_task(telescope.upload_downloaded.__name__)
                 self.assert_blob_integrity(env.download_bucket, blob_name(release.download_path), release.download_path)
 
                 # Test that file extracted
-                env.run_task(telescope.extract.__name__, dag, execution_date)
+                env.run_task(telescope.extract.__name__)
                 self.assertEqual(5, len(release.extract_files))
                 for i, file in enumerate(natsorted(release.extract_files)):
                     expected_file_hash = self.extract_file_hashes[i]
                     self.assert_file_integrity(file, expected_file_hash, "md5")
 
                 # Test that files transformed
-                env.run_task(telescope.transform.__name__, dag, execution_date)
+                env.run_task(telescope.transform.__name__)
                 self.assertEqual(5, len(release.transform_files))
                 for i, file in enumerate(natsorted(release.transform_files)):
                     expected_file_hash = self.transform_hashes[i]
                     self.assert_file_integrity(file, expected_file_hash, "md5")
 
                 # Test that transformed files uploaded
-                env.run_task(telescope.upload_transformed.__name__, dag, execution_date)
+                env.run_task(telescope.upload_transformed.__name__)
                 for file in release.transform_files:
                     self.assert_blob_integrity(env.transform_bucket, blob_name(file), file)
 
                 # Test that data loaded into BigQuery
-                env.run_task(telescope.bq_load.__name__, dag, execution_date)
+                env.run_task(telescope.bq_load.__name__)
                 table_id = (
                     f"{self.project_id}.{dataset_id}."
                     f"{bigquery_sharded_table_id(telescope.dag_id, release.release_date)}"
@@ -190,7 +190,7 @@ class TestCrossrefMetadataTelescope(ObservatoryTestCase):
                     release.extract_folder,
                     release.transform_folder,
                 )
-                env.run_task(telescope.cleanup.__name__, dag, execution_date)
+                env.run_task(telescope.cleanup.__name__)
                 self.assert_cleanup(download_folder, extract_folder, transform_folder)
 
     @patch("academic_observatory_workflows.workflows.crossref_metadata_telescope.BaseHook.get_connection")
