@@ -19,6 +19,7 @@ from __future__ import annotations
 import os
 from datetime import timedelta
 from typing import Dict, List
+from unittest.mock import patch
 
 import pendulum
 from airflow.exceptions import AirflowException
@@ -61,12 +62,12 @@ class TestDoiWorkflow(ObservatoryTestCase):
             1,
             name="Curtin University",
             grid_id="grid.1032.0",
+            ror_id="https://ror.org/02n415q13",
             country_code="AUS",
             country_code_2="AU",
             region="Oceania",
             subregion="Australia and New Zealand",
             types="Education",
-            home_repo="curtin.edu.au",
             country="Australia",
             coordinates="-32.005931, 115.894397",
         )
@@ -74,12 +75,12 @@ class TestDoiWorkflow(ObservatoryTestCase):
             2,
             name="Australian National University",
             grid_id="grid.1001.0",
+            ror_id="https://ror.org/019wvm592",
             country_code="AUS",
             country_code_2="AU",
             region="Oceania",
             subregion="Australia and New Zealand",
             types="Education",
-            home_repo="anu.edu.au",
             country="Australia",
             coordinates="-35.2778, 149.1205",
         )
@@ -87,12 +88,12 @@ class TestDoiWorkflow(ObservatoryTestCase):
             3,
             name="University of Auckland",
             grid_id="grid.9654.e",
+            ror_id="https://ror.org/03b94tp07",
             country_code="NZL",
             country_code_2="NZ",
             region="Oceania",
             subregion="Australia and New Zealand",
             types="Education",
-            home_repo="auckland.ac.nz",
             country="New Zealand",
             coordinates="-36.852304, 174.767734",
         )
@@ -120,8 +121,7 @@ class TestDoiWorkflow(ObservatoryTestCase):
                 "crossref_metadata_sensor": ["check_dependencies"],
                 "crossref_fundref_sensor": ["check_dependencies"],
                 "geonames_sensor": ["check_dependencies"],
-                "grid_sensor": ["check_dependencies"],
-                "mag_sensor": ["check_dependencies"],
+                "ror_sensor": ["check_dependencies"],
                 "open_citations_sensor": ["check_dependencies"],
                 "unpaywall_sensor": ["check_dependencies"],
                 "orcid_sensor": ["check_dependencies"],
@@ -130,7 +130,7 @@ class TestDoiWorkflow(ObservatoryTestCase):
                 "create_datasets": [
                     "create_crossref_events",
                     "create_crossref_fundref",
-                    "create_grid",
+                    "create_ror",
                     "create_mag",
                     "create_orcid",
                     "create_open_citations",
@@ -138,7 +138,7 @@ class TestDoiWorkflow(ObservatoryTestCase):
                 ],
                 "create_crossref_events": ["create_doi"],
                 "create_crossref_fundref": ["create_doi"],
-                "create_grid": ["create_doi"],
+                "create_ror": ["create_doi"],
                 "create_mag": ["create_doi"],
                 "create_orcid": ["create_doi"],
                 "create_open_citations": ["create_doi"],
@@ -222,8 +222,7 @@ class TestDoiWorkflow(ObservatoryTestCase):
             dataset_id_crossref_events=fake_dataset_id,
             dataset_id_crossref_metadata=fake_dataset_id,
             dataset_id_crossref_fundref=fake_dataset_id,
-            dataset_id_grid=fake_dataset_id,
-            dataset_id_iso=fake_dataset_id,
+            dataset_id_ror=fake_dataset_id,
             dataset_id_mag=fake_dataset_id,
             dataset_id_orcid=fake_dataset_id,
             dataset_id_open_citations=fake_dataset_id,
@@ -236,7 +235,7 @@ class TestDoiWorkflow(ObservatoryTestCase):
 
         with env.create(task_logging=True):
             # Make dag
-            start_date = pendulum.datetime(year=2021, month=5, day=9)
+            start_date = pendulum.datetime(year=2021, month=10, day=10)
             workflow = DoiWorkflow(
                 intermediate_dataset_id=intermediate_dataset_id,
                 dashboards_dataset_id=dashboards_dataset_id,
@@ -247,7 +246,7 @@ class TestDoiWorkflow(ObservatoryTestCase):
             )
 
             # Disable dag check on dag run sensor
-            for sensor in workflow.sensors:
+            for sensor in workflow.operators[0]:
                 sensor.check_exists = False
                 sensor.grace_period = timedelta(seconds=1)
 
@@ -258,34 +257,34 @@ class TestDoiWorkflow(ObservatoryTestCase):
             expected_state = "success"
             with env.create_dag_run(doi_dag, start_date):
                 for task_id in DoiWorkflow.SENSOR_DAG_IDS:
-                    ti = env.run_task(f"{task_id}_sensor", doi_dag, execution_date=start_date)
+                    ti = env.run_task(f"{task_id}_sensor")
                     self.assertEqual(expected_state, ti.state)
 
             # Run Dummy Dags
-            execution_date = pendulum.datetime(year=2021, month=5, day=16)
-            release_date = pendulum.datetime(year=2021, month=5, day=22)
+            execution_date = pendulum.datetime(year=2021, month=10, day=17)
+            release_date = pendulum.datetime(year=2021, month=10, day=23)
             release_suffix = release_date.strftime("%Y%m%d")
             expected_state = "success"
             for dag_id in DoiWorkflow.SENSOR_DAG_IDS:
                 dag = make_dummy_dag(dag_id, execution_date)
                 with env.create_dag_run(dag, execution_date):
                     # Running all of a DAGs tasks sets the DAG to finished
-                    ti = env.run_task("dummy_task", dag, execution_date=execution_date)
+                    ti = env.run_task("dummy_task")
                     self.assertEqual(expected_state, ti.state)
 
             # Run end to end tests for DOI DAG
             with env.create_dag_run(doi_dag, execution_date):
                 # Test that sensors go into 'success' state as the DAGs that they are waiting for have finished
                 for task_id in DoiWorkflow.SENSOR_DAG_IDS:
-                    ti = env.run_task(f"{task_id}_sensor", doi_dag, execution_date=execution_date)
+                    ti = env.run_task(f"{task_id}_sensor")
                     self.assertEqual(expected_state, ti.state)
 
                 # Check dependencies
-                ti = env.run_task("check_dependencies", doi_dag, execution_date=execution_date)
+                ti = env.run_task("check_dependencies")
                 self.assertEqual(expected_state, ti.state)
 
                 # Create datasets
-                ti = env.run_task("create_datasets", doi_dag, execution_date=execution_date)
+                ti = env.run_task("create_datasets")
                 self.assertEqual(expected_state, ti.state)
 
                 # Generate fake dataset
@@ -302,11 +301,11 @@ class TestDoiWorkflow(ObservatoryTestCase):
                 # Test that source dataset transformations run
                 for transform in transforms:
                     task_id = f"create_{transform.output_table.table_id}"
-                    ti = env.run_task(task_id, doi_dag, execution_date=execution_date)
+                    ti = env.run_task(task_id)
                     self.assertEqual(expected_state, ti.state)
 
                 # Test create DOI task
-                ti = env.run_task("create_doi", doi_dag, execution_date=execution_date)
+                ti = env.run_task("create_doi")
                 self.assertEqual(expected_state, ti.state)
 
                 # DOI assert table exists
@@ -316,11 +315,12 @@ class TestDoiWorkflow(ObservatoryTestCase):
 
                 # DOI assert correctness of output
                 expected_output = make_doi_table(observatory_dataset)
-                actual_output = self.query_table(observatory_dataset_id, f"doi{release_suffix}", "doi")
+                with patch("observatory.platform.utils.gc_utils.bq_query_bytes_daily_limit_check"):
+                    actual_output = self.query_table(observatory_dataset_id, f"doi{release_suffix}", "doi")
                 self.assert_doi(expected_output, actual_output)
 
                 # Test create book
-                ti = env.run_task("create_book", doi_dag, execution_date=execution_date)
+                ti = env.run_task("create_book")
                 self.assertEqual(expected_state, ti.state)
                 expected_table_id = f"{self.gcp_project_id}.{observatory_dataset_id}.book{release_suffix}"
                 expected_rows = 0
@@ -329,7 +329,7 @@ class TestDoiWorkflow(ObservatoryTestCase):
                 # Test aggregations tasks
                 for agg in DoiWorkflow.AGGREGATIONS:
                     task_id = f"create_{agg.table_id}"
-                    ti = env.run_task(task_id, doi_dag, execution_date=execution_date)
+                    ti = env.run_task(task_id)
                     self.assertEqual(expected_state, ti.state)
 
                     # Aggregation assert table exists
@@ -338,19 +338,22 @@ class TestDoiWorkflow(ObservatoryTestCase):
 
                 # Assert country aggregation output
                 expected_output = make_country_table(observatory_dataset)
-                actual_output = self.query_table(observatory_dataset_id, f"country{release_suffix}", "id, time_period")
+                with patch("observatory.platform.utils.gc_utils.bq_query_bytes_daily_limit_check"):
+                    actual_output = self.query_table(
+                        observatory_dataset_id, f"country{release_suffix}", "id, time_period"
+                    )
                 self.assert_aggregate(expected_output, actual_output)
                 # TODO: test correctness of remaining outputs
 
                 # Test copy to dashboards
-                ti = env.run_task("copy_to_dashboards", doi_dag, execution_date=execution_date)
+                ti = env.run_task("copy_to_dashboards")
                 self.assertEqual(expected_state, ti.state)
                 table_ids = [agg.table_id for agg in DoiWorkflow.AGGREGATIONS] + ["doi"]
                 for table_id in table_ids:
                     self.assert_table_integrity(f"{self.gcp_project_id}.{dashboards_dataset_id}.{table_id}")
 
                 # Test create dashboard views
-                ti = env.run_task("create_dashboard_views", doi_dag, execution_date=execution_date)
+                ti = env.run_task("create_dashboard_views")
                 self.assertEqual(expected_state, ti.state)
                 for table_id in ["country", "funder", "group", "institution", "publisher", "subregion"]:
                     self.assert_table_integrity(f"{self.gcp_project_id}.{dashboards_dataset_id}.{table_id}_comparison")
@@ -359,7 +362,7 @@ class TestDoiWorkflow(ObservatoryTestCase):
                 for agg in DoiWorkflow.AGGREGATIONS:
                     table_id = agg.table_id
                     task_id = f"export_{table_id}"
-                    ti = env.run_task(task_id, doi_dag, execution_date=execution_date)
+                    ti = env.run_task(task_id)
                     self.assertEqual(expected_state, ti.state)
 
                     # Check that the correct tables exist for each aggregation
@@ -463,9 +466,6 @@ class TestDoiWorkflow(ObservatoryTestCase):
             # Check events
             self.assert_doi_events(expected_record["events"], actual_record["events"])
 
-            # Check grids
-            self.assertSetEqual(set(expected_record["grids"]), set(actual_record["grids"]))
-
             # Check affiliations
             self.assert_doi_affiliations(expected_record["affiliations"], actual_record["affiliations"])
 
@@ -520,6 +520,5 @@ class TestDoiWorkflow(ObservatoryTestCase):
         self.assertEqual(len(items_expected_), len(items_actual_))
         items_actual_.sort(key=lambda x: x["identifier"])
         for item_ in items_actual_:
-            item_["home_repo"].sort()
             item_["members"].sort()
         self.assertListEqual(items_expected_, items_actual_)
