@@ -22,18 +22,17 @@ from types import SimpleNamespace
 from unittest.mock import ANY, patch
 
 import pendulum
-from airflow.exceptions import AirflowException, AirflowSkipException
-from airflow.models.connection import Connection
-from airflow.models.variable import Variable
-from botocore.response import StreamingBody
-from click.testing import CliRunner
-
 from academic_observatory_workflows.config import test_fixtures_folder
 from academic_observatory_workflows.workflows.orcid_telescope import (
     OrcidRelease,
     OrcidTelescope,
     transform_single_file,
 )
+from airflow.exceptions import AirflowException, AirflowSkipException
+from airflow.models.connection import Connection
+from airflow.models.variable import Variable
+from botocore.response import StreamingBody
+from click.testing import CliRunner
 from observatory.platform.utils.airflow_utils import AirflowConns, AirflowVars, BaseHook
 from observatory.platform.utils.gc_utils import (
     upload_file_to_cloud_storage,
@@ -225,9 +224,10 @@ class TestOrcidTelescope(ObservatoryTestCase):
                 ti = env.run_task(telescope.bq_load_partition.__name__)
                 self.assertEqual(ti.state, "skipped")
 
-                # Test delete old task is in success state, without doing anything
-                ti = env.run_task(telescope.bq_delete_old.__name__)
-                self.assertEqual(ti.state, "success")
+                # Test delete old task is skipped for the first release
+                with patch("observatory.platform.utils.gc_utils.bq_query_bytes_daily_limit_check"):
+                    ti = env.run_task(telescope.bq_delete_old.__name__)
+                self.assertEqual(ti.state, "skipped")
 
                 # Test append new creates table
                 env.run_task(telescope.bq_append_new.__name__)
@@ -257,13 +257,6 @@ class TestOrcidTelescope(ObservatoryTestCase):
                     next_execution_date=pendulum.datetime(2021, 3, 7),
                 )
 
-                # Test list releases task with files available
-                # ti = env.run_task(telescope.get_release_info.__name__)
-                # start_date, end_date, first_release = ti.xcom_pull(
-                #     key=OrcidTelescope.RELEASE_INFO,
-                #     task_ids=telescope.get_release_info.__name__,
-                #     include_prior_dates=False,
-                # )
                 self.assertEqual(release.end_date + timedelta(days=1), start_date)
                 self.assertEqual(pendulum.today("UTC") - timedelta(days=1), end_date)
                 self.assertFalse(first_release)
@@ -341,7 +334,8 @@ class TestOrcidTelescope(ObservatoryTestCase):
                 self.assert_table_integrity(table_id, expected_rows)
 
                 # Test task deleted rows from main table
-                env.run_task(telescope.bq_delete_old.__name__)
+                with patch("observatory.platform.utils.gc_utils.bq_query_bytes_daily_limit_check"):
+                    env.run_task(telescope.bq_delete_old.__name__)
                 table_id = f"{self.project_id}.{telescope.dataset_id}.{main_table_id}"
                 expected_rows = 1
                 self.assert_table_integrity(table_id, expected_rows)
@@ -419,6 +413,7 @@ class TestOrcidTelescope(ObservatoryTestCase):
     @patch("academic_observatory_workflows.workflows.orcid_telescope.get_aws_conn_info")
     @patch("academic_observatory_workflows.workflows.orcid_telescope.write_modified_record_blobs")
     @patch("academic_observatory_workflows.workflows.orcid_telescope.Variable.get")
+    @patch.dict(os.environ, {"GOOGLE_APPLICATION_CREDENTIALS": "credentials.json"}, clear=True)
     def test_download_transferred(self, mock_variable_get, mock_write_blobs, mock_aws_info, mock_subprocess):
         """Test the download_transferred method of the ORCID release.
 
@@ -444,10 +439,11 @@ class TestOrcidTelescope(ObservatoryTestCase):
                 "gcloud",
                 "auth",
                 "activate-service-account",
-                f'--key-file={os.environ["GOOGLE_APPLICATION_CREDENTIALS"]}',
+                f"--key-file=credentials.json",
             ],
             stdout=-1,
             stderr=-1,
+            env=dict({"GOOGLE_APPLICATION_CREDENTIALS": "credentials.json"}, CLOUDSDK_PYTHON="python3"),
         )
         mock_subprocess.assert_called_with(
             [
@@ -486,10 +482,11 @@ class TestOrcidTelescope(ObservatoryTestCase):
                     "gcloud",
                     "auth",
                     "activate-service-account",
-                    f'--key-file={os.environ["GOOGLE_APPLICATION_CREDENTIALS"]}',
+                    f"--key-file=credentials.json",
                 ],
                 stdout=-1,
                 stderr=-1,
+                env=dict({"GOOGLE_APPLICATION_CREDENTIALS": "credentials.json"}, CLOUDSDK_PYTHON="python3"),
             )
             mock_subprocess.assert_called_with(
                 [
